Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(552)

Unified Diff: components/offline_pages/offline_page_archiver.h

Issue 1843893002: Support resaving offline page right after it is being deleted (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address feedback Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/offline_page_archiver.h
diff --git a/components/offline_pages/offline_page_archiver.h b/components/offline_pages/offline_page_archiver.h
index 5a412a1d8b2311ed93f7998d7919eea5a9cf6c46..72fb8fdd92d523b07f571f9cc37f74b6109e28cf 100644
--- a/components/offline_pages/offline_page_archiver.h
+++ b/components/offline_pages/offline_page_archiver.h
@@ -64,9 +64,11 @@ class OfflinePageArchiver {
virtual ~OfflinePageArchiver() {}
// Starts creating the archive in the |archives_dir|. Once archive is created
// |callback| will be called with the result and additional information.
virtual void CreateArchive(const base::FilePath& archives_dir,
+ int64_t archive_id,
const CreateArchiveCallback& callback) = 0;
};
@@ -64,9 +64,11 @@ class OfflinePageArchiver {
virtual ~OfflinePageArchiver() {}
- // Starts creating the archive in the |archives_dir|. Once archive is created
- // |callback| will be called with the result and additional information.
+ // Starts creating the archive in the |archives_dir| with |archive_id| added
+ // to the archive filename. Once archive is created |callback| will be called
+ // with the result and additional information.
virtual void CreateArchive(const base::FilePath& archives_dir,

Powered by Google App Engine
This is Rietveld 408576698